#[non_exhaustive]
pub enum NovaError {
Show 20 variants InvalidIndex, InvalidStepCircuitIO, InvalidInputLength, InvalidWitnessLength, UnSat, DecompressionError, ProofVerifyError, InvalidCommitmentKeyLength, InvalidNumSteps, InvalidPCS, InvalidSumcheckProof, InvalidInitialInputLength, InvalidStepOutputLength, InternalTranscriptError, InvalidMultisetProof, InvalidProductProof, IncorrectWitness, SynthesisError { reason: String, }, DigestError, InternalError,
}
Errors returned by Nova

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidIndex

returned if the supplied row or col in (row,col,val) tuple is out of range



InvalidStepCircuitIO

returned if the step circuit calls inputize or alloc_io in its synthesize method instead of passing output with the return value



InvalidInputLength

returned if the supplied input is not of the right length



InvalidWitnessLength

returned if the supplied witness is not of the right length



UnSat

returned if the supplied witness is not a satisfying witness to a given shape and instance



DecompressionError

returned when the supplied compressed commitment cannot be decompressed



ProofVerifyError

returned if proof verification fails



InvalidCommitmentKeyLength

returned if the provided commitment key is not of sufficient length



InvalidNumSteps

returned if the provided number of steps is zero



InvalidPCS

returned when an invalid PCS evaluation argument is provided



InvalidSumcheckProof

returned when an invalid sum-check proof is provided



InvalidInitialInputLength

returned when the initial input to an incremental computation differs from a previously declared arity



InvalidStepOutputLength

returned when the step execution produces an output whose length differs from a previously declared arity



InternalTranscriptError

returned when the transcript engine encounters an overflow of the round number



InvalidMultisetProof

returned when the multiset check fails



InvalidProductProof

returned when the product proof check fails



IncorrectWitness

returned when the consistency with public IO and assignment used fails



SynthesisError

Fields

reason: String

The reason for circuit synthesis failure

return when error during synthesis



DigestError

returned when there is an error creating a digest



InternalError

returned when the prover cannot prove the provided statement due to completeness error