pub struct AllocatedBit { /* private fields */ }Expand description
Represents a variable in the constraint system which is guaranteed to be either zero or one.
Implementations
Sourceimpl AllocatedBit
impl AllocatedBit
Sourcepub fn get_value(&self) -> Option<bool>
pub fn get_value(&self) -> Option<bool>
Get inner value of AllocatedBit
Sourcepub fn get_variable(&self) -> Variable
pub fn get_variable(&self) -> Variable
Get inner Variable of AllocatedBit
Sourcepub fn from_parts_unchecked(variable: Variable, value: Option<bool>) -> Self
pub fn from_parts_unchecked(variable: Variable, value: Option<bool>) -> Self
Construct an AllocatedBit from a variable and value without adding constraints.
Safety (Logical)
The caller MUST ensure that:
- The variable has already been constrained to be boolean (0 or 1) elsewhere
- The value correctly reflects the variable’s assignment
This is useful when a variable is known to be boolean due to constraints added separately (e.g., via linear combinations that enforce 0/1).
Sourcepub fn alloc_conditionally<Scalar, CS>(
cs: CS,
value: Option<bool>,
must_be_false: &AllocatedBit,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
pub fn alloc_conditionally<Scalar, CS>(
cs: CS,
value: Option<bool>,
must_be_false: &AllocatedBit,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
Allocate a variable in the constraint system which can only be a boolean value. Further, constrain that the boolean is false unless the condition is false.
Sourcepub fn alloc<Scalar, CS>(
cs: CS,
value: Option<bool>,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
pub fn alloc<Scalar, CS>(
cs: CS,
value: Option<bool>,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
Allocate a variable in the constraint system which can only be a boolean value.
Sourcepub fn xor<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
pub fn xor<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
Performs an XOR operation over the two operands, returning
an AllocatedBit.
Sourcepub fn and<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
pub fn and<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
Performs an AND operation over the two operands, returning
an AllocatedBit.
Sourcepub fn and_not<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
pub fn and_not<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
Calculates a AND (NOT b).
Sourcepub fn nor<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
pub fn nor<Scalar, CS>(
cs: CS,
a: &Self,
b: &Self,
) -> Result<Self, SynthesisError>where
Scalar: PrimeField,
CS: ConstraintSystem<Scalar>,
Calculates (NOT a) AND (NOT b).