pub struct TestShapeCS<E: Engine> {
pub constraints: Vec<(LinearCombination<E::Scalar>, LinearCombination<E::Scalar>, LinearCombination<E::Scalar>, String)>,
/* private fields */
}Expand description
TestShapeCS is a ConstraintSystem for creating R1CSShapes for a circuit.
Fields
constraints: Vec<(LinearCombination<E::Scalar>, LinearCombination<E::Scalar>, LinearCombination<E::Scalar>, String)>All constraints added to the TestShapeCS.
Implementations
Sourceimpl<E: Engine> TestShapeCS<E>where
E::Scalar: PrimeField,
impl<E: Engine> TestShapeCS<E>where
E::Scalar: PrimeField,
Sourcepub fn num_constraints(&self) -> usize
pub fn num_constraints(&self) -> usize
Returns the number of constraints defined for this TestShapeCS.
Sourcepub fn num_inputs(&self) -> usize
pub fn num_inputs(&self) -> usize
Returns the number of inputs defined for this TestShapeCS.
Sourcepub fn pretty_print_list(&self) -> Vec<String>
pub fn pretty_print_list(&self) -> Vec<String>
Print all public inputs, aux inputs, and constraint names.
Sourcepub fn pretty_print(&self) -> String
pub fn pretty_print(&self) -> String
Print all inputs and a detailed representation of each constraint.