pub struct AllocatedPointNonInfinity<E: Engine> {
pub x: AllocatedNum<E::Base>,
pub y: AllocatedNum<E::Base>,
}Expand description
AllocatedPoint but one that is guaranteed to be not infinity
Fields
x: AllocatedNum<E::Base>The x-coordinate of the point.
y: AllocatedNum<E::Base>The y-coordinate of the point.
Implementations
Sourceimpl<E: Engine> AllocatedPointNonInfinity<E>
impl<E: Engine> AllocatedPointNonInfinity<E>
Sourcepub fn from_allocated_point(p: &AllocatedPoint<E>) -> Self
pub fn from_allocated_point(p: &AllocatedPoint<E>) -> Self
Turns an AllocatedPoint into an AllocatedPointNonInfinity (assumes it is not infinity)
Sourcepub fn to_allocated_point(
&self,
is_infinity: &AllocatedNum<E::Base>,
) -> Result<AllocatedPoint<E>, SynthesisError>
pub fn to_allocated_point( &self, is_infinity: &AllocatedNum<E::Base>, ) -> Result<AllocatedPoint<E>, SynthesisError>
Returns an AllocatedPoint from an AllocatedPointNonInfinity
Sourcepub fn add_incomplete<CS>(
&self,
cs: CS,
other: &Self,
) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<E::Base>,
pub fn add_incomplete<CS>(
&self,
cs: CS,
other: &Self,
) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<E::Base>,
Add two points assuming self != +/- other
Sourcepub fn double_incomplete<CS: ConstraintSystem<E::Base>>(
&self,
cs: CS,
) -> Result<Self, SynthesisError>
pub fn double_incomplete<CS: ConstraintSystem<E::Base>>( &self, cs: CS, ) -> Result<Self, SynthesisError>
doubles the point; since this is called with a point not at infinity, it is guaranteed to be not infinity
Sourcepub fn conditionally_select<CS: ConstraintSystem<E::Base>>(
cs: CS,
a: &Self,
b: &Self,
condition: &Boolean,
) -> Result<Self, SynthesisError>
pub fn conditionally_select<CS: ConstraintSystem<E::Base>>( cs: CS, a: &Self, b: &Self, condition: &Boolean, ) -> Result<Self, SynthesisError>
If condition outputs a otherwise outputs b
Sourcepub fn alloc<CS: ConstraintSystem<E::Base>>(
cs: CS,
coords: Option<(E::Base, E::Base)>,
) -> Result<AllocatedPointNonInfinity<E>, SynthesisError>
pub fn alloc<CS: ConstraintSystem<E::Base>>( cs: CS, coords: Option<(E::Base, E::Base)>, ) -> Result<AllocatedPointNonInfinity<E>, SynthesisError>
Allocate a new point from coordinates.
Sourcepub fn conditionally_select2<CS: ConstraintSystem<E::Base>>(
cs: CS,
a: &Self,
b: &Self,
condition: &AllocatedNum<E::Base>,
) -> Result<AllocatedPointNonInfinity<E>, SynthesisError>
pub fn conditionally_select2<CS: ConstraintSystem<E::Base>>( cs: CS, a: &Self, b: &Self, condition: &AllocatedNum<E::Base>, ) -> Result<AllocatedPointNonInfinity<E>, SynthesisError>
Conditional select using an AllocatedNum instead of Boolean.
Sourcepub fn enforce_equal<CS: ConstraintSystem<E::Base>>(
&self,
cs: CS,
other: &Self,
) -> Result<(), SynthesisError>
pub fn enforce_equal<CS: ConstraintSystem<E::Base>>( &self, cs: CS, other: &Self, ) -> Result<(), SynthesisError>
Enforce that self equals other.