pub struct RelaxedR1CSInstance<E: Engine> { /* private fields */ }Expand description
A type that holds a Relaxed R1CS instance
Implementations
Sourceimpl<E: Engine> RelaxedR1CSInstance<E>
impl<E: Engine> RelaxedR1CSInstance<E>
Sourcepub fn default(
_ck: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::CommitmentKey,
S: &R1CSShape<E>,
) -> RelaxedR1CSInstance<E>
pub fn default( _ck: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::CommitmentKey, S: &R1CSShape<E>, ) -> RelaxedR1CSInstance<E>
Produces a default RelaxedR1CSInstance given R1CSGens and R1CSShape
Sourcepub fn from_r1cs_instance(
ck: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::CommitmentKey,
S: &R1CSShape<E>,
instance: &R1CSInstance<E>,
) -> RelaxedR1CSInstance<E>
pub fn from_r1cs_instance( ck: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::CommitmentKey, S: &R1CSShape<E>, instance: &R1CSInstance<E>, ) -> RelaxedR1CSInstance<E>
Initializes a new RelaxedR1CSInstance from an R1CSInstance
Sourcepub fn comm_W(
&self,
) -> &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment
pub fn comm_W( &self, ) -> &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment
Returns a reference to the commitment to the witness W.
This is useful for commitment operations.
Sourcepub fn comm_E(
&self,
) -> &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment
pub fn comm_E( &self, ) -> &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment
Returns a reference to the commitment to the error vector E.
This is useful for commitment operations.
Sourcepub fn X(&self) -> &[E::Scalar]
pub fn X(&self) -> &[E::Scalar]
Returns a reference to the public inputs/outputs.
This is useful for public IO access.
Sourcepub fn u(&self) -> E::Scalar
pub fn u(&self) -> E::Scalar
Returns the relaxation factor u.
This is useful for accessing the relaxation factor in folding.
Sourcepub fn new(
S: &R1CSShape<E>,
comm_W: <<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment,
comm_E: <<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment,
u: E::Scalar,
X: Vec<E::Scalar>,
) -> Result<RelaxedR1CSInstance<E>, NovaError>
pub fn new( S: &R1CSShape<E>, comm_W: <<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment, comm_E: <<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment, u: E::Scalar, X: Vec<E::Scalar>, ) -> Result<RelaxedR1CSInstance<E>, NovaError>
Creates a RelaxedR1CSInstance from its component parts.
This is useful for constructing instances when commitments are computed separately from instance creation.
Validates that X has the correct length for the given shape.
Sourcepub fn from_r1cs_instance_unchecked(
comm_W: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment,
X: &[E::Scalar],
) -> RelaxedR1CSInstance<E>
pub fn from_r1cs_instance_unchecked( comm_W: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment, X: &[E::Scalar], ) -> RelaxedR1CSInstance<E>
Initializes a new RelaxedR1CSInstance from an R1CSInstance
Sourcepub fn fold(
&self,
U2: &R1CSInstance<E>,
comm_T: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment,
r: &E::Scalar,
) -> RelaxedR1CSInstance<E>
pub fn fold( &self, U2: &R1CSInstance<E>, comm_T: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment, r: &E::Scalar, ) -> RelaxedR1CSInstance<E>
Folds an incoming R1CSInstance into the current one
Sourcepub fn fold_relaxed(
&self,
U2: &RelaxedR1CSInstance<E>,
comm_T: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment,
r: &E::Scalar,
) -> RelaxedR1CSInstance<E>
pub fn fold_relaxed( &self, U2: &RelaxedR1CSInstance<E>, comm_T: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::Commitment, r: &E::Scalar, ) -> RelaxedR1CSInstance<E>
Folds an incoming RelaxedR1CSInstance into the current one
Sourcepub fn derandomize(
&self,
dk: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::DerandKey,
r_W: &E::Scalar,
r_E: &E::Scalar,
) -> RelaxedR1CSInstance<E>
pub fn derandomize( &self, dk: &<<E as Engine>::CE as CommitmentEngineTrait<E>>::DerandKey, r_W: &E::Scalar, r_E: &E::Scalar, ) -> RelaxedR1CSInstance<E>
Derandomizes the instance by removing the randomness from the commitments.