pub struct SparseMatrix<F: PrimeField> {
pub data: Vec<F>,
pub indices: Vec<usize>,
pub indptr: Vec<usize>,
pub cols: usize,
}Expand description
CSR format sparse matrix, We follow the names used by scipy. Detailed explanation here: https://stackoverflow.com/questions/52299420/scipy-csr-matrix-understand-indptr
Fields
data: Vec<F>all non-zero values in the matrix
indices: Vec<usize>column indices
indptr: Vec<usize>row information
cols: usizenumber of columns
Implementations
Sourceimpl<F: PrimeField> SparseMatrix<F>
impl<F: PrimeField> SparseMatrix<F>
Sourcepub fn new(matrix: &[(usize, usize, F)], rows: usize, cols: usize) -> Self
pub fn new(matrix: &[(usize, usize, F)], rows: usize, cols: usize) -> Self
Construct from the COO representation; Vec<usize(row), usize(col), F>. We assume that the rows are sorted during construction.
Sourcepub fn get_row_unchecked(
&self,
ptrs: &[usize; 2],
) -> impl Iterator<Item = (&F, &usize)>
pub fn get_row_unchecked( &self, ptrs: &[usize; 2], ) -> impl Iterator<Item = (&F, &usize)>
Retrieves the data for row slice [i..j] from ptrs.
We assume that ptrs is indexed from indptrs and do not check if the
returned slice is actually a valid row.
Sourcepub fn multiply_vec(&self, vector: &[F]) -> Vec<F>
pub fn multiply_vec(&self, vector: &[F]) -> Vec<F>
Multiply by a dense vector; uses rayon/gpu.
Sourcepub fn multiply_vec_unchecked(&self, vector: &[F]) -> Vec<F>
pub fn multiply_vec_unchecked(&self, vector: &[F]) -> Vec<F>
Multiply by a dense vector; uses rayon/gpu. This does not check that the shape of the matrix/vector are compatible.