Module commitment

Module commitment 

This module defines a collection of traits that define the behavior of a commitment engine We require the commitment engine to provide a commitment to vectors with a single group element

Traits

CommitmentEngineTrait
A trait that ties different pieces of the commitment generation together
CommitmentTrait
This trait defines the behavior of the commitment
Len
A trait that helps determine the length of a structure. Note this does not impose any memory representation constraints on the structure.
ScalarMul
A helper trait for types implementing scalar multiplication.