Len

Trait Len 

pub trait Len {
    // Required method
    fn length(&self) -> usize;
}
A trait that helps determine the length of a structure. Note this does not impose any memory representation constraints on the structure.

Required Methods

fn length(&self) -> usize

Returns the length of the structure.

Implementors

Source

impl<E: Engine> Len for nova_snark::provider::hyperkzg::CommitmentKey<E>
where E::GE: PairingGroup,

Source

impl<E: Engine> Len for nova_snark::provider::pedersen::CommitmentKey<E>
where E::GE: DlogGroup,