pub trait TranscriptReprTrait<G: Group>: Send + Sync {
// Required method
fn to_transcript_bytes(&self) -> Vec<u8> ⓘ;
}Expand description
This trait allows types to implement how they want to be added to TranscriptEngine
Required Methods
Sourcefn to_transcript_bytes(&self) -> Vec<u8> ⓘ
fn to_transcript_bytes(&self) -> Vec<u8> ⓘ
returns a byte representation of self to be added to the transcript