pub trait Len {
// Required method
fn length(&self) -> usize;
}Expand description
A trait that helps determine the length of a structure. Note this does not impose any memory representation constraints on the structure.
pub trait Len {
// Required method
fn length(&self) -> usize;
}A trait that helps determine the length of a structure. Note this does not impose any memory representation constraints on the structure.